@@ -8,8 +8,8 @@
 
 use Latin9;
 
-BEGIN { $| = 1; print "1..1\n"; }
-
+$| = 1;
+print "1..1\n";
 print "ok - 1\n";
 
 ######################### End of black magic.
